jactorch.transforms.image.functional
====================================

.. automodule:: jactorch.transforms.image.functional

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      pad
      pad_multiple_of
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: pad

.. autofunction:: pad_multiple_of


